@@ -5,11 +5,7 @@ from django.conf import settings
 from django.conf.urls.defaults import patterns
 
 
-if not hasattr(settings, 'STATICMEDIA_URL'):
-    settings.STATICMEDIA_URL = '/appmedia'
-
-if not hasattr(settings, 'STATICMEDIA_MOUNTS'):
-    settings.STATICMEDIA_MOUNTS = tuple()
+class StaticMediaNotFound(Exception): pass
 
 
 def get_mount_points():
@@ -25,13 +21,13 @@ def get_mount_points():
     """
     mounts = []
 
-    url_prefix = settings.STATICMEDIA_URL
+    url_prefix = getattr(settings, 'STATICMEDIA_URL', '/appmedia')
     if url_prefix.endswith('/'):
         url_prefix = url_prefix[:-1]
 
     # collect mounts specified in the settings, we want these to be
     # first since they also serve as overrides for the app mounts
-    for mount_url, mount_path in settings.STATICMEDIA_MOUNTS:
+    for mount_url, mount_path in getattr(settings, 'STATICMEDIA_MOUNTS', []):
         if mount_url.endswith('/'):
             mount_url = mount_url[:-1]
         mounts.append((mount_url, mount_path))
@@ -55,26 +51,45 @@ def get_mount_points():
     return mounts
 
 
-def resolve(base_url):
+def resolve(media_name):
     """
-    Resolve the given relative url against the available mount points.
+    Resolve the given relative path against the available mount points.
 
     First, the mount points specified by the 'STATICMEDIA_MOUNTS'
     settings are checked, followed by static media mount points for
     each installed app that has one. The relative url is prefixed with
     each given mount point's path on the filesystem, and if a file
-    exists in this location, then `base_url` is prefixed with the
+    exists in this location, then `media_name` is prefixed with the
     mount point's url prefix.
+
+    Returns a tuple in the form (absolute_media_url, media_path).
     """
-    if base_url.startswith('/'):
-        base_url = base_url[1:]
-    relative_path = base_url.replace('/', os.sep)
+    if media_name.startswith('/'):
+        media_name = media_name[1:]
+    relative_path = media_name.replace('/', os.sep)
 
     for mount_url, mount_path in get_mount_points():
-        if os.path.lexists(os.path.join(mount_path, relative_path)):
-            return posixpath.join(mount_url, base_url)
+        media_path = os.path.join(mount_path, relative_path)
+        if os.path.lexists(media_path):
+            return (
+                posixpath.join(mount_url, media_name),
+                media_path)  
 
-    return ''
+    raise StaticMediaNotFound(media_name)
+
+
+def url(media_name):
+    """
+    Resolve the absolute url for the given static media.
+    """
+    return resolve(media_name)[0]
+
+
+def path(media_name):
+    """
+    Resolve the path on the given static media.
+    """
+    return resolve(media_name)[1]
 
 
 def serve(show_indexes=False, debug=False):
