@@ -23,7 +23,7 @@ def apache(fp=None, **options):
             'Alias "%s" "%s"' % (mount_url, mount_path))
         if 'diroptions' in options:
             directives.append(
-                '<Directory "%s">Options %s</Directory>' % (
+                '<Directory "%s">\n    Options %s\n</Directory>' % (
                      mount_path, options['diroptions']))
     if fp:
         fp.write('\n'.join(directives))
